@@ -38,6 +38,8 @@ DEVICES = [
     "qemu-armv7",
     "qemu-arm64",
     "qemu-i386",
+    "qemu-mips32",
+    "qemu-mips32el",
     "qemu-mips64",
     "qemu-mips64el",
     "qemu-ppc64",
@@ -52,6 +54,8 @@ KERNELS = {
     "qemu-armv7": "https://storage.tuxboot.com/armv7/zImage",
     "qemu-arm64": "https://storage.tuxboot.com/arm64/Image",
     "qemu-i386": "https://storage.tuxboot.com/i386/bzImage",
+    "qemu-mips32": "https://storage.tuxboot.com/mips32/vmlinux",
+    "qemu-mips32el": "https://storage.tuxboot.com/mips32el/vmlinux",
     "qemu-mips64": "https://storage.tuxboot.com/mips64/vmlinux",
     "qemu-mips64el": "https://storage.tuxboot.com/mips64el/vmlinux",
     "qemu-ppc64": "https://storage.tuxboot.com/ppc64/vmlinux",
@@ -260,7 +264,7 @@ def _main(options, tmpdir: Path) -> int:
         for line in proc.stderr:
             line = line.rstrip("\n")
             try:
-                data = yaml.load(line, Loader=yaml.CFullLoader)  # type: ignore
+                data = yaml_load(line)
                 if not data or not isinstance(data, dict):
                     debug(options, line)
                     continue
