@@ -4,7 +4,10 @@ import yaml
 try:
     from yaml import CFullLoader as FullLoader  # type: ignore
 except ImportError:
-    from yaml import FullLoader
+    try:
+        from yaml import FullLoader
+    except ImportError:
+        from yaml import Loader as FullLoader
 
     print("Warning: using python yaml loader")
 
